import { Utilities } from '@/util/Utilities';
import {
    DateRange, Form, LoadingService, Modal, ModalService, Select, SelectMultiple,
} from '@zeedhi/common';
import {
    Http, IDictionary, IEventParam, Metadata,
} from '@zeedhi/core';
import { Calendar } from '@zeedhi/zd-calendar';

export class Fm00007000CalendarioControler {
    public modalFiltrar!: Modal;

    public filtroHabilitado!: Boolean;

    public async criarModais() {
        this.modalFiltrar = await ModalService.createFromJsonPost('', { jsonPath: 'fm_00007_000_calendario/modal/fm_00007_000_filtrar' });
    }

    public destruirModais() {
        ModalService.delete(this.modalFiltrar);
    }

    public abrirModalFiltrar() {
        this.modalFiltrar.show();
    }

    public fecharModalFiltrar() {
        this.modalFiltrar.hide();
    }

    public getDados({ component }: any) {
        const dataHoje = new Date();
        const dataInicial = new Date(dataHoje.getFullYear(), dataHoje.getMonth(), 1);
        const dataFinal = new Date(dataHoje.getFullYear(), dataHoje.getMonth() + 1, 0);

        this.postTarefasCalendario({ component }, dataInicial.toLocaleDateString(), dataFinal.toLocaleDateString(), null, null, null, null, null);
    }

    public postTarefasCalendario({ component }: IEventParam<Calendar>, dataInicial: any, dataFinal: any, local: any, localSuperior: any, tipoLocal: any, operador: any, atividade: any) {
        let calendarEvent: any = {};
        component.clearCalendarEvents();
        LoadingService.show();
        Http.post('/getTarefasCalendario', {
            PERIODOINICIAL: dataInicial,
            PERIODOFINAL: dataFinal,
            NRLOCALCLIENTE: local,
            NRLOCALCLIENTEPAI: localSuperior,
            NRTIPOLOCALCLI: tipoLocal,
            NRATIVIDADE: atividade,
            CDOPERADOR: operador,
        }).then((response: IDictionary) => {
            response.data.data.forEach((element: IDictionary) => {
                calendarEvent = {
                    id: element.CODIGO,
                    name: element.NOME,
                    start: this.formatarData(element.DTHORAAGEND),
                    end: this.formatarData(element.DTHRFINALAGEND),
                    description: `Local: ${element.NMLOCALCLIENTE} <br> Operador: ${element.NMOPERADOR} <br> Horário: ${element.DTHORAAGEND.split(' ')[1]} - ${element.DTHRFINALAGEND.split(' ')[1]}`,
                    color: (local != null) ? element.CORATIVIDADE : element.DSCORIDLOCAL,
                };
                component.addCalendarEvents([calendarEvent]);
            });
        }).catch((error: any) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
            this.fecharModalFiltrar();
        });
    }

    public formatarData(data: any) {
        const hora = data.split(' ')[1];
        const dataAmericana = data.split(' ')[0].split('/').reverse().join('-');
        const dataFormatada = `${dataAmericana} ${hora}`;

        return dataFormatada;
    }

    public limparFiltros() {
        const calendario = Metadata.getInstance<Calendar>('calendarioFm');
        Metadata.getInstance<Form>('form-filtros').clearForm();
        this.getDados({ component: calendario });
        this.filtroHabilitado = false;
    }

    public filtrarCalendario() {
        this.filtroHabilitado = true;
        const periodo = Metadata.getInstance<DateRange>('dataFiltro').value;
        const calendario = Metadata.getInstance<Calendar>('calendarioFm');
        const dataInicial = periodo[0];
        const dataFinal = (periodo.length > 1) ? periodo[1] : null;
        const local = Metadata.getInstance<SelectMultiple>('filtro-local').value;
        const localSup = Metadata.getInstance<SelectMultiple>('filtro-local-superior').value;
        const tipoLocal = Metadata.getInstance<SelectMultiple>('filtro-tipoLocal').value;
        const operador = Metadata.getInstance<Select>('filtro-operador').value;
        const atividade = Metadata.getInstance<Select>('filtro-atividade').value;
        const form = Metadata.getInstance<Form>('form-filtros');

        if (Utilities.validateForm(form)) {
            this.postTarefasCalendario({ component: calendario }, dataInicial, dataFinal, local, localSup, tipoLocal, operador, atividade);
        }
    }

    public clickEvento({ component }: any) {
        if (this.filtroHabilitado !== true) {
            const [ano, mes] = component.value.split('-');
            const dataInicial = new Date(ano, mes - 1, 1);
            const dataFinal = new Date(ano, mes, 0);
            this.postTarefasCalendario({ component }, dataInicial.toLocaleDateString(), dataFinal.toLocaleDateString(), null, null, null, null, null);
        }
    }
}
