import {
    DialogService,
    Form, Modal, ModalService, SelectMultiple,
} from '@zeedhi/common';
import { Metadata } from '@zeedhi/core';
import { TekGrid } from '@zeedhi/teknisa-components-common';
import { Utilities } from '@/util/Utilities';

export class Fm00010002IntegracaoSmController {
    private modalNovoRelacionamento!: Modal;

    public visibilidadeGridItens: boolean = false;

    public visibilidadeForm: boolean = true;

    public async abrirModal() {
        this.modalNovoRelacionamento = await ModalService.createFromJson('fm_00010_000_parametrizao_geral/modal/fm_00010_002_novo_relacionamento', true);
        this.modalNovoRelacionamento.show();
    }

    public fecharModal() {
        this.modalNovoRelacionamento.hide();
        this.modalNovoRelacionamento?.destroy();
    }

    public salvarNovoRelacionamento() {
        const form = Metadata.getInstance<Form>('form-novo-relacionamento');
        const gridServicos = Metadata.getInstance<TekGrid>('tek-grid-servicos');
        const selectItens = Metadata.getInstance<SelectMultiple>('NRATIVIDADE').selectValue;

        if (form.validate()) {
            Utilities.save('/salvarRelacionamento', {
                CDSERVORCA: form.value.CDSERVORCA,
                CDTPMEDIDASERV: form.value.CDTPMEDIDASERV,
                ATIVIDADE: selectItens,
            }).then((response: any) => {
                if (response.data.length > 0) {
                    Utilities.showDialog('Item já existente', 'warning', '<br/>Os itens abaixo já estão vinculados com este Serviço e Tipo de Medida. Não é possível criar este relacionamento novamente! <br/><br/>'.concat(response.data.join('<br/>')));
                }
                gridServicos.datasource.get();
                this.fecharModal();
            });
        }
    }

    public rowClickFiltroGrid({ row }: any) {
        this.visibilidadeGridItens = true;
        this.visibilidadeForm = !this.visibilidadeGridItens;

        const gridItens = Metadata.getInstance<TekGrid>('tek-grid-itens-tarefas');
        gridItens.datasource.setFilter({
            CDSERVORCA: row.CDSERVORCA,
            CDTPMEDIDASERV: row.CDTPMEDIDASERV,
        });
    }

    public dialogInativarServicos({ event }: any) {
        Utilities.showConfirmDeleteMessage(event, 'Fm00010002IntegracaoSmController.inativarServicos', 'Inativar Registros', 'Deseja realmente inativar todos os registros selecionados?');
    }

    public inativarServicos() {
        const grid = Metadata.getInstance<TekGrid>('tek-grid-servicos');
        const gridItens = Metadata.getInstance<TekGrid>('tek-grid-itens-tarefas');

        Utilities.deleteInfoGrid('/inativarServicos', { component: grid }).then(() => {
            grid.datasource.get();
            gridItens.reload();
            DialogService.hide();
        });

        if (gridItens.datasource.data.length <= 0) {
            this.visibilidadeGridItens = false;
            this.visibilidadeForm = !this.visibilidadeGridItens;
        }
    }
}
